@@ -26,6 +26,7 @@ from gi.repository import Gio
 from gi.repository import GLib
 from gi.repository import GObject
 import uaclient.api.u.pro.packages.updates.v1 as ua
+import UbuntuDrivers.detect
 
 GdkX11  # pyflakes
 
@@ -367,20 +368,29 @@ class UpdateManager(Gtk.Window):
         lts = di.is_lts(codename)
         if not lts:
             return None
+
+        # Packages that may not be installed but apply to this system
+        # Cache because probing at every startup is expensive
+        pkgs = []
         OEM_PATH = os.path.join(
             GLib.get_user_runtime_dir(), "ubuntu-drivers-oem.package-list"
         )
         if not os.path.exists(OEM_PATH):
-            return None
-
-        # Packages that aren't installed but apply to this system
-        with open(OEM_PATH, "r") as f:
-            self.oem_metapackages |= set(f.read().splitlines())
+            pkgs = UbuntuDrivers.detect.system_device_specific_metapackages(
+                apt_cache=self.cache._cache
+            ).keys()
+            with open(OEM_PATH, "w") as f:
+                f.write("\n".join(pkgs))
+        else:
+            with open(OEM_PATH, "r") as f:
+                pkgs = [pkg for pkg in f.read().splitlines() if
+                        fnmatch.fnmatch(pkg, "oem-*-meta")]
+        self.oem_metapackages |= set(pkgs)
 
         # Packages that are already installed
         for pkg in self.cache:
             if fnmatch.fnmatch(pkg.name, "oem-*-meta") and pkg.installed:
-                self.oem_metapackages.add(pkg)
+                self.oem_metapackages.add(pkg.name)
 
     def _fetch_ua_updates(self, cb=None):
         try:
