@@ -410,6 +410,10 @@ class UpdatesAvailable(InternalDialog):
         self.alert_watcher.check_alert_state()
         self._restore_state()
 
+        if self.window_main.options.install_all:
+            self.window_main.options.install_all = False
+            self.install_all_updates(None, None, None)
+
     def is_auto_update(self):
         update_days = apt_pkg.config.find_i(
             "APT::Periodic::Update-Package-Lists"
