@@ -7,12 +7,11 @@ import unittest
 
 # pycodestyle is overdoing it a bit IMO
 IGNORE_PYCODESTYLE = "E265,E402,W503"
-IGNORE_FILES = (
-)
+IGNORE_FILES = ()
 
 
 class TestPyCodeStyleClean(unittest.TestCase):
-    """ ensure that the tree is pycodestyle clean """
+    """ensure that the tree is pycodestyle clean"""
 
     def test_pycodestyle_clean(self):
         CURDIR = os.path.dirname(os.path.abspath(__file__))
@@ -29,12 +28,14 @@ class TestPyCodeStyleClean(unittest.TestCase):
                     continue
                 py_files.add(os.path.join(dirpath, f))
         ret_code = subprocess.call(
-            ["pycodestyle",
-             "--ignore={0}".format(IGNORE_PYCODESTYLE)] + list(py_files))
+            ["pycodestyle", "--ignore={0}".format(IGNORE_PYCODESTYLE)]
+            + list(py_files)
+        )
         self.assertEqual(0, ret_code)
 
 
 if __name__ == "__main__":
     import logging
+
     logging.basicConfig(level=logging.DEBUG)
     unittest.main()
